@@ -1,5 +1,6 @@
 from django import forms
 from django.contrib import admin
+from django.contrib.admin.sites import NotRegistered
 from django.contrib.auth.admin import UserAdmin
 from django.contrib.auth.models import User, Group
 
@@ -16,8 +17,15 @@ class CustomUserAdmin(UserAdmin):
     fieldsets = None
     form = UserForm
     search_fields = ('=username',)
+    list_filter = ('is_staff', 'is_superuser', 'is_active')
 
+try:
+    admin.site.unregister(User)
+    admin.site.register(User, CustomUserAdmin)
+except NotRegistered:
+    pass
 
-admin.site.unregister(User)
-admin.site.unregister(Group)
-admin.site.register(User, CustomUserAdmin)
+try:
+    admin.site.unregister(Group)
+except NotRegistered:
+    pass
